@@ -60,7 +60,7 @@ class ClickReviewException(Exception):
 class ClickReview(object):
     '''This class represents click reviews'''
     # Convenience to break out common types of clicks (eg, app, scope,
-    # framework, click service)
+    # click service)
     app_allowed_peer_hooks = ["account-application",
                               "account-service",
                               "apparmor",
@@ -75,8 +75,6 @@ class ClickReview(object):
                                 "scope",
                                 ]
     # FIXME: when apparmor-policy is implemented, use this
-    # framework_allowed_peer_hooks = ["apparmor-policy"]
-    framework_allowed_peer_hooks = []
     service_allowed_peer_hooks = ["apparmor",
                                   "bin-path",
                                   "snappy-systemd",
@@ -86,16 +84,19 @@ class ClickReview(object):
     # optional snappy fields here (may be required by appstore)
     snappy_optional = ["architecture",
                        "binaries",
+                       "config",
                        "frameworks",
                        "icon",
+                       "immutable-config",
                        "integration",
+                       "oem",
                        "services",
                        "source",
                        "type",
                        "vendor",  # replaces maintainer
                        ]
 
-    def __init__(self, fn, review_type, peer_hooks=None):
+    def __init__(self, fn, review_type, peer_hooks=None, overrides=None):
         self.click_package = fn
         self._check_path_exists()
         if not self.click_package.endswith(".click") and \
@@ -144,11 +145,20 @@ class ClickReview(object):
         if pkg_yaml is not None:
             try:
                 self.pkg_yaml = yaml.safe_load(pkg_yaml)
-            except Exception as e:
+            except Exception:
                 error("Could not load package.yaml. Is it properly formatted?")
             self._verify_package_yaml_structure()
             self.is_snap = True
 
+            #  default to 'app'
+            if 'type' not in self.pkg_yaml:
+                self.pkg_yaml['type'] = 'app'
+
+        self.is_snap_oem = False
+        if self.is_snap and 'type' in self.pkg_yaml and \
+           self.pkg_yaml['type'] == 'oem':
+            self.is_snap_oem = True
+
         # Get a list of all unpacked files, except DEBIAN/
         self.pkg_files = []
         self._list_all_files()
@@ -164,6 +174,7 @@ class ClickReview(object):
         self.valid_frameworks = self._extract_click_frameworks()
 
         self.peer_hooks = peer_hooks
+        self.overrides = overrides if overrides is not None else {}
 
     def _extract_click_frameworks(self):
         '''Extract installed click frameworks'''
@@ -251,6 +262,14 @@ class ClickReview(object):
                     error("manifest malformed: '%s' is not str or list:\n%s" %
                           (f, mp))
 
+        # FIXME: this is kinda gross but the best we can do while we are trying
+        # to support clicks and native snaps
+        if 'type' in self.manifest and self.manifest['type'] == 'oem':
+            if 'hooks' in self.manifest:
+                error("'hooks' present in manifest with type 'oem'")
+            # mock up something for other tests
+            self.manifest['hooks'] = {'oem': {'reviewtools': True}}
+
         # Not required by click, but required by appstore. 'hooks' is assumed
         # to be present in other checks
         if 'hooks' not in self.manifest:
@@ -300,7 +319,7 @@ class ClickReview(object):
                     (isinstance(self.pkg_yaml[f], str) or
                      isinstance(self.pkg_yaml[f], list)):
                     error("yaml malformed: '%s' is not str or list:\n%s" %
-                          (f, mp))
+                          (f, yp))
                 elif f in ["binaries", "services"] and not \
                         isinstance(self.pkg_yaml[f], list):
                     error("yaml malformed: '%s' is not list:\n%s" % (f, yp))
@@ -609,3 +628,20 @@ def recursive_rm(dirPath, contents_only=False):
             recursive_rm(path)
     if contents_only is False:
         os.rmdir(dirPath)
+
+
+def run_click_check(cls):
+    if len(sys.argv) < 2:
+        error("Must give path to click package")
+
+    # extract args
+    fn = sys.argv[1]
+    if len(sys.argv) > 2:
+        overrides = json.loads(sys.argv[2])
+    else:
+        overrides = None
+
+    review = cls(fn, overrides=overrides)
+    review.do_checks()
+    rc = review.do_report()
+    sys.exit(rc)
