@@ -229,7 +229,8 @@ class ClickReviewLint(ClickReview):
                     t = 'error'
                     s = 'If arch=multi, manifest architecture needs to ' + \
                         'comprise of only compiled architectures.'
-            elif control['Architecture'] != self.manifest['architecture']:
+            elif control['Architecture'] != self.manifest['architecture'] and \
+                    not self.is_snap:  # snappy doesn't use this field; ignore
                 t = 'error'
                 s = "Architecture=%s " % control['Architecture'] + \
                     "does not match manifest architecture=%s" % \
@@ -845,7 +846,8 @@ exit 1
             t = 'error'
             s = "not a valid architecture: %s" % my_dict['architecture']
         elif isinstance(my_dict['architecture'], list):
-            archs_list.remove("all")
+            if not self.is_snap:
+                archs_list.remove("all")
             bad_archs = []
             for a in my_dict['architecture']:
                 if a not in archs_list:
