@@ -1,6 +1,6 @@
 '''cr_online_accounts.py: click online accounts'''
 #
-# Copyright (C) 2013 Canonical Ltd.
+# Copyright (C) 2013-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 from __future__ import print_function
 
-from clickreviews.cr_common import ClickReview, error, open_file_read, msg
+from clickreviews.cr_common import ClickReview, error
 import os
 # http://lxml.de/tutorial.html
 import lxml.etree as etree
@@ -24,7 +24,7 @@ import lxml.etree as etree
 
 class ClickReviewAccounts(ClickReview):
     '''This class represents click lint reviews'''
-    def __init__(self, fn):
+    def __init__(self, fn, overrides=None):
         peer_hooks = dict()
         peer_hooks['account-application'] = dict()
         peer_hooks['account-application']['allowed'] = \
@@ -54,7 +54,8 @@ class ClickReviewAccounts(ClickReview):
         peer_hooks['account-qml-plugin']['allowed'] = \
             peer_hooks['account-qml-plugin']['required']
 
-        ClickReview.__init__(self, fn, "online_accounts", peer_hooks)
+        ClickReview.__init__(self, fn, "online_accounts", peer_hooks=peer_hooks,
+                             overrides=overrides)
 
         self.accounts_files = dict()
         self.accounts = dict()
@@ -100,8 +101,7 @@ class ClickReviewAccounts(ClickReview):
                 tree = etree.parse(fn)
                 xml = tree.getroot()
             except Exception as e:
-                error("accounts xml unparseable: %s (%s):\n%s" % (bn, str(e),
-                      contents))
+                error("accounts xml unparseable: %s (%s)" % (bn, str(e)))
             return (fn, xml)
 
     def check_application(self):
@@ -126,7 +126,6 @@ class ClickReviewAccounts(ClickReview):
             t = 'info'
             n = '%s_%s_id' % (app, account_type)
             s = "OK"
-            expected_id = "%s_%s" % (self.manifest["name"], app)
             if "id" in self.accounts[app][account_type].keys():
                 t = 'warn'
                 s = "Found 'id' in application tag"
@@ -174,7 +173,6 @@ class ClickReviewAccounts(ClickReview):
             t = 'info'
             n = '%s_%s_id' % (app, account_type)
             s = "OK"
-            expected_id = "%s_%s" % (self.manifest["name"], app)
             if "id" in self.accounts[app][account_type].keys():
                 t = 'warn'
                 s = "Found 'id' in service tag"
@@ -223,7 +221,6 @@ class ClickReviewAccounts(ClickReview):
             t = 'info'
             n = '%s_%s_id' % (app, account_type)
             s = "OK"
-            expected_id = "%s_%s" % (self.manifest["name"], app)
             if "id" in self.accounts[app][account_type].keys():
                 t = 'warn'
                 s = "Found 'id' in provider tag"
