@@ -72,7 +72,6 @@ class ClickReviewSecurity(ClickReview):
                                 'policy_version']
         self.redflag_fields = ['abstractions',
                                'binary',
-                               'policy_vendor',
                                'read_path',
                                'template_variables',
                                'write_path']
@@ -107,10 +106,13 @@ class ClickReviewSecurity(ClickReview):
             'ubuntu-sdk-14.10': {
                 'policy_version': 1.2,
             },
-            'ubuntu-core-15.04': {
-                'policy_vendor': 'ubuntu-snappy',
+            'ubuntu-sdk-15.04': {
                 'policy_version': 1.3,
             },
+            'ubuntu-core-15.04': {
+                'policy_vendor': 'ubuntu-core',
+                'policy_version': 15.04,
+            },
         }
         framework_overrides = self.overrides.get('framework', {})
         self._override_framework_policies(framework_overrides)
