@@ -1,6 +1,6 @@
 '''cr_url dispatcher.py: click url_dispatcher'''
 #
-# Copyright (C) 2014 Canonical Ltd.
+# Copyright (C) 2014-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 from __future__ import print_function
 
-from clickreviews.cr_common import ClickReview, error, open_file_read, msg
+from clickreviews.cr_common import ClickReview, error, open_file_read
 import json
 import os
 
@@ -25,14 +25,15 @@ import os
 
 class ClickReviewUrlDispatcher(ClickReview):
     '''This class represents click lint reviews'''
-    def __init__(self, fn):
+    def __init__(self, fn, overrides=None):
         peer_hooks = dict()
         my_hook = 'urls'
         peer_hooks[my_hook] = dict()
         peer_hooks[my_hook]['allowed'] = ClickReview.app_allowed_peer_hooks
         peer_hooks[my_hook]['required'] = []
 
-        ClickReview.__init__(self, fn, "url_dispatcher", peer_hooks=peer_hooks)
+        ClickReview.__init__(self, fn, "url_dispatcher", peer_hooks=peer_hooks,
+                             overrides=overrides)
 
         self.required_keys = ['protocol']
         self.optional_keys = ['domain-suffix']
